@@ -25,7 +25,6 @@ import os
 import re
 import unicodedata
 
-
 try:
     import pycountry
 except ImportError:
@@ -379,7 +378,7 @@ cldr_plural_categories = [
     "other",
 ]
 
-"""List of plural tags generated from CLDR 32.0.1 using
+"""List of plural tags generated from CLDR 41.0.0 using
 https://github.com/WeblateOrg/language-data
 """
 plural_tags = {
@@ -393,6 +392,7 @@ plural_tags = {
     "asa": ["one", "other"],
     "ast": ["one", "other"],
     "az": ["one", "other"],
+    "bal": ["one", "other"],
     "be": ["one", "few", "many"],
     "bem": ["one", "other"],
     "bez": ["one", "other"],
@@ -414,6 +414,7 @@ plural_tags = {
     "cy": ["zero", "one", "two", "few", "many", "other"],
     "da": ["one", "other"],
     "de": ["one", "other"],
+    "doi": ["one", "other"],
     "dsb": ["one", "two", "few", "other"],
     "dv": ["one", "other"],
     "dz": ["other"],
@@ -421,7 +422,7 @@ plural_tags = {
     "el": ["one", "other"],
     "en": ["one", "other"],
     "eo": ["one", "other"],
-    "es": ["one", "other"],
+    "es": ["one", "many", "other"],
     "et": ["one", "other"],
     "eu": ["one", "other"],
     "fa": ["one", "other"],
@@ -429,7 +430,7 @@ plural_tags = {
     "fi": ["one", "other"],
     "fil": ["one", "other"],
     "fo": ["one", "other"],
-    "fr": ["one", "other"],
+    "fr": ["one", "many", "other"],
     "fur": ["one", "other"],
     "fy": ["one", "other"],
     "ga": ["one", "two", "few", "many", "other"],
@@ -443,6 +444,7 @@ plural_tags = {
     "haw": ["one", "other"],
     "he": ["one", "two", "many", "other"],
     "hi": ["one", "other"],
+    "hnj": ["other"],
     "hr": ["one", "few", "other"],
     "hsb": ["one", "two", "few", "other"],
     "hu": ["one", "other"],
@@ -454,7 +456,7 @@ plural_tags = {
     "in": ["other"],
     "io": ["one", "other"],
     "is": ["one", "other"],
-    "it": ["one", "other"],
+    "it": ["one", "many", "other"],
     "iu": ["one", "two", "other"],
     "iw": ["one", "two", "many", "other"],
     "ja": ["other"],
@@ -521,19 +523,20 @@ plural_tags = {
     "osa": ["other"],
     "pa": ["one", "other"],
     "pap": ["one", "other"],
+    "pcm": ["one", "other"],
     "pl": ["one", "few", "many"],
     "prg": ["zero", "one", "other"],
     "ps": ["one", "other"],
-    "pt": ["one", "other"],
-    "pt_PT": ["one", "other"],
+    "pt": ["one", "many", "other"],
+    "pt_PT": ["one", "many", "other"],
     "rm": ["one", "other"],
     "ro": ["one", "few", "other"],
     "rof": ["one", "other"],
-    "root": ["other"],
     "ru": ["one", "few", "many"],
     "rwk": ["one", "other"],
     "sah": ["other"],
     "saq": ["one", "other"],
+    "sat": ["one", "two", "other"],
     "sc": ["one", "other"],
     "scn": ["one", "other"],
     "sd": ["one", "other"],
@@ -573,11 +576,13 @@ plural_tags = {
     "tl": ["one", "other"],
     "tn": ["one", "other"],
     "to": ["other"],
+    "tpi": ["other"],
     "tr": ["one", "other"],
     "ts": ["one", "other"],
     "tzm": ["one", "other"],
     "ug": ["one", "other"],
     "uk": ["one", "few", "many"],
+    "und": ["other"],
     "ur": ["one", "other"],
     "uz": ["one", "other"],
     "ve": ["one", "other"],
@@ -786,7 +791,7 @@ def normalize_code(code):
     return code.replace("_", "-").replace("@", "-").lower()
 
 
-__normalised_languages = {normalize_code(key) for key in languages.keys()}
+__normalised_languages = {normalize_code(key) for key in languages}
 
 
 def simplify_to_common(language_code):
@@ -809,4 +814,4 @@ def get_language(code):
     if "_" in code:
         # convert ab_cd → ab_CD
         code = "{}_{}".format(code.split("_")[0], code.split("_", 1)[1].upper())
-    return languages.get(code, None)
+    return languages.get(code)
